<?php
/**
 * Logger
 * @package     Me
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Me_Logger
{
    /** ログレベル間隔 */
    const LOG_LEVEL_RANGE = 300;
    /** ログ番号オフセット。 */
    const LOG_NUMBER_OFFSET = 1000;
    /** 改行コード */
    const LINE_FEED_CODE = "\r\n";

    /**
     * ログ（secure, system, info）書き出し
     * @param integer $code
     * @param array $replace_text_list
     * @return string $message
     */
    static public function log($code = 1, $replace_text_list = array())
    {
        // ログレベル設定を確認
        $log_level = Me_Config::get('log_level', 'log');
        if (!$log_level || !is_numeric($log_level)) {
            // 設定されていないか、数字でない場合は、ログは出力しない。
            return;
        } else if ($log_level > 0) {
            $threshold = $log_level * self::LOG_LEVEL_RANGE + self::LOG_NUMBER_OFFSET;
            if ($code >= $threshold) {
                // しきい値以上のログは書き出さない。
                return;
            }
        }
        // ログレベル名を取得
        $level_name = '';
        if ($code >= 1000 && $code < 1300) {
            $level_name = '[SECURE:' . $code . '] ';
        } else if ($code >= 1300 && $code < 1600) {
            $level_name = '[SYSTEM:' . $code . '] ';
        } else if ($code >= 1600 && $code < 1900) {
            $level_name = '[INFO:' . $code . '] ';
        } else {
            $level_name = '[UNKNOWN' . $code . '] ';
        }

        // メッセージリソースを読み込む
        $messages = Me_Util::read_var_file('def/message/ja/log_message.php');
        // 文字列置換
        $message = vsprintf($messages[$code], $replace_text_list);
        
        self::write_log($level_name . $message);
        return $message;
    }

    /**
     * ログ書き出し
     * @param string $message
     * @return null
     */
    static public function write_log($message)
    {
        // 基本情報取得
        $user_name = '-';
        if (isset($_SESSION['login_user']->user_name)) {
            $user_name = $_SESSION['login_user']->user_name;
        }
        $message_list = array(
            date('[Y/m/d H:i:s]'),
            //$login_user->user_name,
            $user_name,
            $_SERVER['REMOTE_ADDR'],
            $message . self::LINE_FEED_CODE
        );

        // ログファイル名
        $filename = date('Y-m') . '.log';

        // ログ書き出し
        error_log(implode(' ', $message_list), 3, DATA_ROOT . '/log/' . $filename);
        return;
    }
}
