<?php
/**
 * Metag File
 * @package     Metag
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Metag_File extends Metag
{
    /**
     * タグタイプ
     * @var string
     */
    public $node_type = 'file';
    /**
     * 表示名
     * @var string
     */
    public $display_name = 'ファイル (file)';
    /**
     * ブロック要素かどうか
     * @var boolean
     */
    public $is_block = false;
    /**
     * style attribute
     * @var string
     */
    public $style;
    /**
     * 編集アイコンの表示
     * @var string
     */
    public $edit_icon;
    /**
     * 属性リスト
     * @var array
     */
    public $attr_list = array(
        'id' => 'id',
        'style' => 'style',
        'edit_icon' => 'edit_icon',
        'ref_id' => 'ref_id',
        'ref_page_id' => 'ref_page_id',
    );

    /**
     * 編集view出力
     * @param array $row
     */
    public function edit_view($row)
    {
        // 参照指定がある場合は子HTMLを出力
        if (strlen($this->ref_id) > 0) {
            $child = $this->get_child_node();
            echo $child->node_value;
            return;
        }

        if ($this->edit_icon === 'on') {
            h::no_escape('<img class="me_edit_icon" src="' . CMS_PATH . '/app/assets/img/silk/attach.png" width="16" height="16" title="ファイルアップロード" onclick="'
                . $this->get_open_method($row) . '"'
                . $this->get_icon_style($row['repeat_no']) . '>'
                . '<span class="metag">'
                . $this->output($row, true)
                . '</span>'
            );
        } else {
            h::no_escape('<span class="metag" onclick="' . $this->get_open_method($row) . '"'
                . $this->get_style($row['repeat_no']) . '>'
                . $this->output($row, true)
                . '</span>');
        }
    }

    /**
     * 出力
     * @param array $row
     * @param boolean $edit_mode
     * @return string
     */
    public function output($row, $edit_mode = false)
    {
        $str = Metag_Logic::BLANK;
        if ($edit_mode) {
            if (strlen($row['node_value']) > 0) {
                $str = $row['attr']['filename'];
            }
        } else {
            if (strlen($row['node_value']) < 1) {
                return '';
            } else {
                $str = $row['attr']['filename'];
            }
        }
        $node_value = $row['node_value'];

        $file_attr = array();

        if ($edit_mode) {
            // border色指定
            $border_color = $this->get_border_color($row['repeat_no']);
            $file_attr['style'] = 'border: 1px solid ' . $border_color . '; cursor: pointer;';
            $file_attr['onclick'] = $this->get_open_method($row);
        }

        $row['url'] = $row['node_value'];

        $this->set_url($row);
        list($a_open, $a_close) = $this->get_a($row);

        return $a_open . $str . $a_close;
    }

    /**
     * editor
     */
    public function print_editor_attr()
    {
        $str = '';
        if (!empty($this->style)) {
            $str .= ' style="' . Me_Util::html_escape($this->style) . '"';
        }
        h::no_escape($str);
    }

    /**
     * タグ編集
     */
    public function set_post_data()
    {
        $mapping = $this->attr_list;
        $mapping['selected_text'] = 'selected_text';
        Me_Util::post_data_to_object($this, $mapping);
    }
}