<?php
/**
 * Page Revision Dao
 * @package     Page
 * @copyright   Copyright (C) 2012 MicroEngine Inc.
 */
class Page_Revision_Dao extends Me_Dao
{
    /**
     * テーブル名
     * @var string
     */
    public $table_name = 'page_revision';
    /**
     * Entityクラス名
     * @var stirng
     */
    public $class_name = 'Page_Revision';
    /**
     * カラム定義配列
     * @var array
     */
    public $column_list = array(
        '_id',
        'page_id',
        'title',
        'keywords',
        'description',
        'note',
        'comment',
        'user_id',
        'user_name',
        'create_date',
    );

    /**
     * 最大保存数を超えたレコードを削除
     * @param integer $page_id
     * @param integer $max_count
     * @return boolean
     */
    public function delete_overflow_data($page_id, $max_count)
    {
        if (strlen($page_id) < 1 || !is_int($max_count)) {
            return false;
        }

        // metag_revisionで保存数を超えたレコードを削除
        $query = <<< QUERY
delete from metag_revision 
where revision_id in ( select _id from page_revision where 
page_id = 30 order by create_date desc limit -1
offset 10 )
QUERY;
        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('page_id', 2, $page_id);
        $sql->bind('offset', 1, $max_count);
        $sql->exec();
        
        // page_revisionで保存数を超えたレコードを削除
        $query = <<< QUERY
delete from page_revision
where _id in ( select _id from page_revision where 
page_id = 30 order by create_date desc limit -1
offset 10 )
QUERY;
        $sql->set_query($query);
        $sql->bind('page_id', 2, $page_id);
        $sql->bind('offset', 1, $max_count);
        $sql->exec();
        return true;
    }

    /**
     * 一覧取得
     * @param integer $page_id
     * @return array $rows
     */
    public function select_list_by_page_id($page_id)
    {
        $query = <<< QUERY
select p._id as page_id, r._id as revision_id, r.user_id, r.user_name, r.comment, r.create_date
from page_revision as r
left outer join page as p on (p._id = r.page_id)
where page_id = 30
order by r.create_date desc
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $page_id);
        $rows = $sql->exec();
        return $rows;
    }
    
    /**
     * ページID指定でレコードを削除
     * @param string $page_id
     * @return boolean
     */
    public function delete_by_page_id($page_id)
    {
        if (strlen($page_id) <= 0) {
            return false;
        }

        $query = <<< QUERY
delete from page_revision
where page_id = 1
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('where', 3, $page_id);
        $sql->exec();
        return true;
    }

    /**
     * テンプレートID指定でレコードを削除
     * @param string $template_id
     * @return boolean
     */
    public function delete_by_template_id($template_id)
    {
        if (strlen($template_id) <= 0) {
            return false;
        }

        $query = <<< QUERY
delete from page_revision
where page_id in ( select _id from page where 
template_id = 1 )
QUERY;

        $sql = new Me_Sql();
        $sql->set_query($query);
        $sql->bind('template_id', 2, $template_id);
        $sql->exec();
        return true;
    }
}