<?php
/**
 * Upgrade Logic
 * @package     Upgrade
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Upgrade_Logic
{

    /**
     * コンストラクタ
     */
    public function __construct()
    {
        
    }

    /**
     * アップグレード処理実行
     * @param integer $old_num
     * @param integer $new_num
     */
    public function execute_upgrade($old_num, $new_num)
    {
        // スキーマ情報取得
        $meinfo_dao = new Meinfo_Dao();
        $meinfo = $meinfo_dao->select(1, 'Meinfo');

        // 各アップグレードメソッドを実行する
        for ($i = ++$old_num; $i <= $new_num; $i++) {
            $method = 'upgrade_' . $i;
            $this->$method();

            // DBのスキーマバージョンを上げる
            $meinfo->schema_version = $i;
            $meinfo_dao->update($meinfo);

            // アップグレードしたことを表示する。
            echo 'スキーマバージョンを ' . $i . ' にアップグレードしました。<br>';
            // ログ書き出し
            Me_Logger::log(1351, $i);
        }
    }

    /**
     * スキーマバージョン2へのアップグレード処理
     */
    private function upgrade_2()
    {
        // DBスキーマ変更
        // SQL文
        $query_list = array(
            'ALTER TABLE template ADD COLUMN main_template TEXT;',
            'ALTER TABLE template ADD COLUMN cond TEXT;',
            'ALTER TABLE page ADD COLUMN char_code TEXT;',
            "ALTER TABLE user ADD COLUMN default_access TEXT DEFAULT 'allow';",
            'ALTER TABLE user ADD COLUMN path_config TEXT;',
        );
        // SQL実行
        $sql = new Me_Sql();
        foreach ($query_list as $query) {
            $sql->set_query($query);
            $sql->exec();
        }

        // ディレクトリ作成
        $dir_path = DATA_ROOT . '/log'; 
        if (!file_exists($dir_path) && !Me_Util::mkdir($dir_path, 0755, true)) {
            throw new Me_Exception(301, $dir_path);
        }
    }

    /**
     * スキーマバージョン3へのアップグレード処理
     */
    private function upgrade_3()
    {
        // DBスキーマ変更
        // SQL文
        $query_list = array(
            'ALTER TABLE page ADD COLUMN user_id INTEGER;',
            'ALTER TABLE page ADD COLUMN user_name TEXT;',
            'drop table if exists page_revision;',
            'drop table if exists metag_revision;',
            'drop table if exists content_image;',
            'drop table if exists content_file;',
            'drop table if exists page_draft;',
            'drop table if exists metag_draft;',
            'ALTER TABLE user ADD COLUMN failure_count INTEGER DEFAULT 1;',
            'ALTER TABLE user ADD COLUMN failure_date INTEGER;',
        );
        // SQL実行
        $sql = new Me_Sql();
        foreach ($query_list as $query) {
            $sql->set_query($query);
            $sql->exec();
        }

        $query = <<< QUERY
create table page_revision (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    page_id INTEGER,
    title TEXT,
    keywords TEXT,
    description TEXT,
    note TEXT,
    comment TEXT,
    user_id INTEGER,
    user_name TEXT,
    create_date INTEGER
);
QUERY;
        $sql->set_query($query);
        $sql->exec();

        $query = <<< QUERY
create table metag_revision (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    revision_id INTEGER,
    page_id INTEGER,
    repeat_id TEXT,
    repeat_no INTEGER,
    id TEXT,
    node_value TEXT,
    url TEXT,
    attr TEXT
);
QUERY;
        $sql->set_query($query);
        $sql->exec();

        $query = <<< QUERY
create index idx_metag_revision_revision_id on metag_revision(page_id);
QUERY;
        $sql->set_query($query);
        $sql->exec();
        
        $query = <<< QUERY
create table content_image (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    file_name TEXT,
    file_path TEXT,
    page_id INTEGER,
    page_path TEXT,
    user_id INTEGER,
    user_name TEXT,
    create_date INTEGER
);
QUERY;
        $sql->set_query($query);
        $sql->exec();

       $query = <<< QUERY
create table content_file (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    file_name TEXT,
    file_path TEXT,
    page_id INTEGER,
    page_path TEXT,
    user_id INTEGER,
    user_name TEXT,
    create_date INTEGER
);
QUERY;
        $sql->set_query($query);
        $sql->exec();

       $query = <<< QUERY
create table page_draft (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    page_id INTEGER,
    title TEXT,
    keywords TEXT,
    description TEXT,
    note TEXT,
    comment TEXT,
    user_id INTEGER,
    user_name TEXT,
    create_date INTEGER,
    update_date INTEGER
);
QUERY;
        $sql->set_query($query);
        $sql->exec();

        $query = <<< QUERY
create table metag_draft (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    page_id INTEGER,
    repeat_id TEXT,
    repeat_no INTEGER,
    id TEXT,
    node_value TEXT,
    url TEXT,
    attr TEXT
);

QUERY;
        $sql->set_query($query);
        $sql->exec();

        $query = <<< QUERY
create index idx_metag_draft_page_id on metag_draft(page_id);
QUERY;
        $sql->set_query($query);
        $sql->exec();

        // サムネイルディレクトリ作成
        $dir_path = DOCUMENT_ROOT . UPLOAD_PATH . '/thumbs'; 
        if (!file_exists($dir_path) && !Me_Util::mkdir($dir_path, 0755, true)) {
            throw new Me_Exception(301, $dir_path);
        }
        // ディレクトリ参照対策としてindex.htmlを作成する。
        Me_Util::write_file($dir_path . '/index.html', 'index.html');
        
        // ファイル用ディレクトリの参照対策
        $file_index = DOCUMENT_ROOT . UPLOAD_PATH . '/files/index.html';
        if (!file_exists($file_index)) {
            Me_Util::write_file($file_index, 'index.html', true);
        }
    }

    /**
     * スキーマバージョン4へのアップグレード処理
     */
    private function upgrade_4()
    {
        // DBスキーマ変更
        // SQL文
        $query_list = array(
            'ALTER TABLE page_draft ADD COLUMN file_name TEXT;',
        );
        // SQL実行
        $sql = new Me_Sql();
        foreach ($query_list as $query) {
            $sql->set_query($query);
            $sql->exec();
        }
    }
}